@@ -2,6 +2,7 @@ package TestApp;
 
 use strict;
 use warnings;
+use MRO::Compat;
 
 use Catalyst;
 
@@ -59,10 +60,16 @@ sub foo5 : Global {
     $c->forward('TestApp::View::JSON');
 }
 
+sub foo6 : Global {
+    my( $self, $c ) = @_;
+    $c->stash->{json_foo} = "\x{5bae}\x{5ddd}";
+    $c->forward('TestApp::View::JSON2');
+}
+
 sub finalize_error {
     my $c = shift;
     $c->res->header('X-Error' => $c->error->[0]);
-    $c->NEXT::finalize_error;
+    $c->next::method;
 }
 
 1;
